from unittest import mock

from fedora_messaging.api import Message

from resultsdb_listener import consumer


example_message = Message(
    topic="org.centos.prod.ci.koji-build.test.queued",
    body={
        "artifact": {
            "component": "rust-miniz_oxide_c_api",
            "id": 37704421,
            "issuer": "ignatenkobrain",
            "nvr": "rust-miniz_oxide_c_api-0.2.3-1.fc32",
            "scratch": False,
            "source": "git+https://src.fedoraproject.org/rpms/"
            "rust-miniz_oxide_c_api.git#"
            "e3e54e569d1b74166c006b9046c49c2815d26f54",
            "type": "koji-build",
        },
        "contact": {
            "docs": "https://pagure.io/standard-test-roles",
            "email": "ci@lists.fedoraproject.org",
            "irc": "#fedora-ci",
            "name": "fedora-ci",
            "team": "fedora-ci",
            "url": "https://jenkins-continuous-infra.apps.ci.centos.org/",
        },
        "generated_at": "2019-09-17T13:38:23.692Z",
        "pipeline": {
            "build": "384836",
            "id": "f8b36f3e-a019-4710-bcc2-6b2bcf95556b",
            "name": "fedora-build-pipeline-trigger",
        },
        "run": {
            "log": "https://jenkins-continuous-infra.apps.ci.centos.org/"
            "job/fedora-build-pipeline-trigger/384836/console",
            "rebuild": "https://jenkins-continuous-infra.apps.ci.centos.org/"
            "job/fedora-build-pipeline-trigger/384836/rebuild/parameterized",
            "url": "https://jenkins-continuous-infra.apps.ci.centos.org/"
            "blue/organizations/jenkins/fedora-build-pipeline-trigger/"
            "detail/fedora-build-pipeline-trigger/384836/pipeline/",
        },
        "test": {
            "category": "functional",
            "namespace": "fedora-ci.koji-build",
            "type": "tier0",
        },
        "version": "0.2.1",
    },
)
example_message.id = "random_uuid"


class TestKojiBuildQueued(object):
    @mock.patch("resultsdb_listener.consumer.senders")
    def test_parse_example_message(self, senders):
        processor = mock.MagicMock()
        senders.get_sender.return_value = processor
        cons = consumer.Consumer()
        cons(example_message)

        assert processor().send.call_count == 1
        processor().send.assert_called_with(
            {
                "build_id": "384836",
                "build_url": "https://jenkins-continuous-infra.apps.ci.centos"
                ".org/blue/organizations/jenkins/fedora-build-pipeline-trigger"
                "/detail/fedora-build-pipeline-trigger/384836/pipeline/",
                "repo": "rust-miniz_oxide_c_api",
                "nvr": "rust-miniz_oxide_c_api-0.2.3-1.fc32",
                "item": "rust-miniz_oxide_c_api-0.2.3-1.fc32",
                "scratch": False,
                "username": "ignatenkobrain",
                "koji_task_id": 37704421,
                "namespace": "fedora-ci.koji-build",
                "type": "koji_build",
                "test_type": "tier0",
                "category": "functional",
                "topic": "org.centos.prod.ci.koji-build.test.queued",
                "msg_id": "random_uuid",
            }
        )
