from unittest import mock

from fedora_messaging.api import Message

from resultsdb_listener import consumer


example_message = Message(
    topic="org.centos.prod.ci.pipeline.image.test.smoke.complete",
    body={
        "CI_TYPE": "custom",
        "CI_NAME": "ci-pipeline-ostree-image-boot-sanity",
        "topic": "org.centos.prod.ci.pipeline.image.test.smoke.complete",
        "build_id": "82",
        "build_url": "https://ci.centos.org/job/"
        "cci-pipeline-ostree-image-boot-sanity/82/",
        "image_url": "http://artifacts.ci.centos.org/artifacts/"
        "fedora-atomic/f26/images/fedora-atomic-26.85-c2dcff5e8d4637a.qcow2",
        "image_name": "fedora-atomic-26.85-c2dcff5e8d4637a.qcow2",
        "type": "qcow2",
        "compose_url": "http://artifacts.ci.centos.org/artifacts/"
        "fedora-atomic/f26/ostree",
        "compose_rev": "c2dcff5e8d4637a6cb19dd0f3e867b48b3d3b6fa05"
        "28dd2d64de23169f9221df",
        "branch": "f26",
        "ref": "fedora/f26/x86_64/atomic-host",
        "rev": "N/A",
        "repo": "N/A",
        "namespace": "rpms",
        "username": "fedora-atomic",
        "test_guidance": "<comma-separated-list-of-test-suites-to-run>",
        "message-content": "",
        "status": "<SUCCESS/FAILURE/ABORTED/ABORTED>",
    },
)
example_message.id = "random_uuid"


class TestPipelineImageTestSmokeComplete(object):
    @mock.patch("resultsdb_listener.consumer.senders")
    def test_parse_example_message(self, senders):
        processor = mock.MagicMock()
        senders.get_sender.return_value = processor
        cons = consumer.Consumer()
        cons(example_message)

        assert processor().send.call_count == 1
        processor().send.assert_called_with(
            {
                "msg_id": "random_uuid",
                "build_id": "82",
                "build_url": "https://ci.centos.org/job/"
                "cci-pipeline-ostree-image-boot-sanity/82/",
                "branch": "f26",
                "ref": "fedora/f26/x86_64/atomic-host",
                "rev": "N/A",
                "repo": "N/A",
                "namespace": "rpms",
                "username": "fedora-atomic",
                "status": "<SUCCESS/FAILURE/ABORTED/ABORTED>",
                "topic": "org.centos.prod.ci.pipeline.image.test."
                "smoke.complete",
                "compose_url": "http://artifacts.ci.centos.org/artifacts/"
                "fedora-atomic/f26/ostree",
            }
        )
